var tar = require("tar");
var fs = require("fs");
var zlib = require("zlib");

var r = fs.createReadStream("cb-never-called-1.0.0-trunc.tgz");

r.pipe(zlib.Unzip())
.pipe(tar.Extract())
.on("entry", function(e){
	console.log("ENTRY:",e.path);
})
.on("error", function(er){
	console.log("err",er);
})
.on("close", function(){
	console.log("close");
});
